use wccg_models::activity::Activity;
use wread_data_mongodb::crud_repository;
use wread_data_mongodb::mongodb::{
    bson::{doc, Document},
    error::Error,
    Database,
};

use wread_data_mongodb::mongodb::{
    options::UpdateModifications,
    results::{DeleteResult, InsertOneResult, UpdateResult},
};

const COLLECTION_NAME: &str = "activities";

pub async fn get_by_external_activity_id(
    external_activity_id: &String,
    external_source_name: &str,
    db: &Database,
) -> Result<Option<Activity>, Error> {
    crud_repository::find_one(
        doc! {"externalActivityId": external_activity_id, "externalSourceName": external_source_name, },
        COLLECTION_NAME,
        &db,
    ).await
}

pub async fn get_by_rider_id(rider_id: &String, db: &Database) -> Result<Vec<Activity>, Error> {
    crud_repository::find(doc! {"riderId": rider_id }, COLLECTION_NAME, &db).await
}

pub async fn get_by_rider_id_newest_first(
    rider_id: &String,
    db: &Database,
) -> Result<Vec<Activity>, Error> {
    crud_repository::find_with_sort(
        doc! {"riderId": rider_id },
        doc! {"startTimestamp": -1 },
        COLLECTION_NAME,
        &db,
    )
    .await
}

pub async fn get_by_rider_id_and_timestamp_range(
    rider_id: &String,
    from_timestamp: &i64,
    to_timestamp: &i64,
    db: &Database,
) -> Result<Vec<Activity>, Error> {
    crud_repository::find_with_sort(
        doc! {"riderId": rider_id, "startTimestamp": {"$gte": from_timestamp, "$lte": to_timestamp }},
        doc! {"startTimestamp": -1 },
        COLLECTION_NAME,
        &db,
    ).await
}

pub async fn add(activity: &Activity, db: &Database) -> Result<InsertOneResult, Error> {
    crud_repository::add(activity, COLLECTION_NAME, db).await
}

pub async fn update(
    query: Document,
    update: impl Into<UpdateModifications>,
    db: &Database,
) -> Result<UpdateResult, Error> {
    crud_repository::update_one(query, update, None, COLLECTION_NAME, db).await
}

pub async fn _delete(query: Document, db: &Database) -> Result<DeleteResult, Error> {
    crud_repository::delete_one(query, None, COLLECTION_NAME, db).await
}

pub async fn delete_for_external_activity_id(
    external_activity_id: &String,
    external_source_name: &str,
    db: &Database,
) -> Result<DeleteResult, Error> {
    let delete_query = doc! {"externalActivityId": external_activity_id, "externalSourceName": external_source_name};
    crud_repository::delete_one(delete_query, None, COLLECTION_NAME, db).await
}
