use wccg_models::activity::ActivityType;
use wread_data_mongodb::mongodb::bson::{doc, Document};

fn get_activity_type_name(activity_type: &ActivityType) -> Option<String> {
    let activity_type_name = match activity_type {
        ActivityType::Ride => Some(String::from("ride")),
        ActivityType::Run => Some(String::from("run")),
        ActivityType::Swim => Some(String::from("swim")),
        ActivityType::Walk => Some(String::from("walk")),
        _ => None,
    };

    activity_type_name
}

pub fn get_activity_stats_update_document(
    activity_type: &ActivityType,
    distance: f32,
    count: i32,
    commute_distance: f32,
    commute_count: i32,
) -> Option<Document> {
    if let Some(activity_type_name) = get_activity_type_name(&activity_type) {
        let distance_field = format!("{}Stats.distance", &activity_type_name);
        let count_field = format!("{}Stats.count", &activity_type_name);
        let commute_distance_field = format!("{}Stats.commuteDistance", &activity_type_name);
        let commute_count_field = format!("{}Stats.commuteCount", &activity_type_name);

        Some(
            doc! {"$inc": { distance_field: distance, count_field: count, commute_distance_field: commute_distance, commute_count_field: commute_count }},
        )
    } else {
        None
    }
}
