use super::helpers;
use wccg_models::activity::ActivityType;
use wccg_models::activity::OverallSummary;
use wccg_models::any::Any;
use wread_data_mongodb::crud_repository;
use wread_data_mongodb::mongodb::{bson::doc, Database};

const COLLECTION_NAME: &str = "overallSummary";

pub async fn increment_activity_stats(
    activity_type: &ActivityType,
    distance: f32,
    count: i32,
    commute_distance: f32,
    commute_count: i32,
    db: &Database,
) {
    log::trace!("increment_activity_stats");
    //TODO: Return result

    init_overall_summary(db).await;

    if let Some(update_document) = helpers::get_activity_stats_update_document(
        activity_type,
        distance,
        count,
        commute_distance,
        commute_count,
    ) {
        crud_repository::update_one(doc! {}, update_document, None, COLLECTION_NAME, db)
            .await
            .unwrap();
    } else {
        log::trace!(
            "None from get_activity_stats_update_document for {:?}",
            &activity_type
        );
    }
}

async fn init_overall_summary(db: &Database) {
    //TODO: Return result
    let overall_summary = crud_repository::find_one::<Any>(doc! {}, COLLECTION_NAME, db)
        .await
        .unwrap();

    if let None = overall_summary {
        let empty_overall_summary = OverallSummary::default();
        crud_repository::add(&empty_overall_summary, COLLECTION_NAME, db)
            .await
            .unwrap();
    }
}
